#[repr(C)]pub struct Affine3 {
pub matrix3: Mat3,
pub translation: Vec3,
}Expand description
A 3D affine transform, which can represent translation, rotation, scaling and shear.
Fields
matrix3: Mat3translation: Vec3Implementations
Sourceimpl Affine3
impl Affine3
Sourcepub const ZERO: Affine3
pub const ZERO: Affine3
The degenerate zero transform.
This transforms any finite vector and point to zero. The zero transform is non-invertible.
Sourcepub const IDENTITY: Affine3
pub const IDENTITY: Affine3
The identity transform.
Multiplying a vector with this returns the same vector.
Sourcepub const fn from_cols(
x_axis: Vec3,
y_axis: Vec3,
z_axis: Vec3,
w_axis: Vec3,
) -> Affine3
pub const fn from_cols( x_axis: Vec3, y_axis: Vec3, z_axis: Vec3, w_axis: Vec3, ) -> Affine3
Creates an affine transform from three column vectors.
Sourcepub fn from_cols_array(m: &[f32; 12]) -> Affine3
pub fn from_cols_array(m: &[f32; 12]) -> Affine3
Creates an affine transform from a [f32; 12] array stored in column major order.
Sourcepub fn to_cols_array(&self) -> [f32; 12]
pub fn to_cols_array(&self) -> [f32; 12]
Creates a [f32; 12] array storing data in column major order.
Sourcepub fn from_cols_array_2d(m: &[[f32; 3]; 4]) -> Affine3
pub fn from_cols_array_2d(m: &[[f32; 3]; 4]) -> Affine3
Creates an affine transform from a [[f32; 3]; 4]
3D array stored in column major order.
If your data is in row major order you will need to transpose the returned
matrix.
Sourcepub fn to_cols_array_2d(&self) -> [[f32; 3]; 4]
pub fn to_cols_array_2d(&self) -> [[f32; 3]; 4]
Creates a [[f32; 3]; 4] 3D array storing data in
column major order.
If you require data in row major order transpose the matrix first.
Sourcepub fn from_cols_slice(slice: &[f32]) -> Affine3
pub fn from_cols_slice(slice: &[f32]) -> Affine3
Creates an affine transform from the first 12 values in slice.
Panics
Panics if slice is less than 12 elements long.
Sourcepub fn write_cols_to_slice(&self, slice: &mut [f32])
pub fn write_cols_to_slice(&self, slice: &mut [f32])
Writes the columns of self to the first 12 elements in slice.
Panics
Panics if slice is less than 12 elements long.
Sourcepub fn from_scale(scale: Vec3) -> Affine3
pub fn from_scale(scale: Vec3) -> Affine3
Creates an affine transform that changes scale. Note that if any scale is zero the transform will be non-invertible.
Sourcepub fn from_quat(rotation: Quat) -> Affine3
pub fn from_quat(rotation: Quat) -> Affine3
Creates an affine transform from the given rotation quaternion.
Sourcepub fn from_axis_angle(axis: Vec3, angle: f32) -> Affine3
pub fn from_axis_angle(axis: Vec3, angle: f32) -> Affine3
Creates an affine transform containing a 3D rotation around a normalized
rotation axis of angle (in radians).
Sourcepub fn from_rotation_x(angle: f32) -> Affine3
pub fn from_rotation_x(angle: f32) -> Affine3
Creates an affine transform containing a 3D rotation around the x axis of
angle (in radians).
Sourcepub fn from_rotation_y(angle: f32) -> Affine3
pub fn from_rotation_y(angle: f32) -> Affine3
Creates an affine transform containing a 3D rotation around the y axis of
angle (in radians).
Sourcepub fn from_rotation_z(angle: f32) -> Affine3
pub fn from_rotation_z(angle: f32) -> Affine3
Creates an affine transform containing a 3D rotation around the z axis of
angle (in radians).
Sourcepub fn from_translation(translation: Vec3) -> Affine3
pub fn from_translation(translation: Vec3) -> Affine3
Creates an affine transformation from the given 3D translation.
Sourcepub fn from_mat3(mat3: Mat3) -> Affine3
pub fn from_mat3(mat3: Mat3) -> Affine3
Creates an affine transform from a 3x3 matrix (expressing scale, shear and rotation)
Sourcepub fn from_mat3_translation(mat3: Mat3, translation: Vec3) -> Affine3
pub fn from_mat3_translation(mat3: Mat3, translation: Vec3) -> Affine3
Creates an affine transform from a 3x3 matrix (expressing scale, shear and rotation) and a translation vector.
Equivalent to Affine3::from_translation(translation) * Affine3::from_mat3(mat3)
Sourcepub fn from_scale_rotation_translation(
scale: Vec3,
rotation: Quat,
translation: Vec3,
) -> Affine3
pub fn from_scale_rotation_translation( scale: Vec3, rotation: Quat, translation: Vec3, ) -> Affine3
Creates an affine transform from the given 3D scale, rotation and
translation.
Equivalent to Affine3::from_translation(translation) * Affine3::from_quat(rotation) * Affine3::from_scale(scale)
Sourcepub fn from_rotation_translation(rotation: Quat, translation: Vec3) -> Affine3
pub fn from_rotation_translation(rotation: Quat, translation: Vec3) -> Affine3
Creates an affine transform from the given 3D rotation and translation.
Equivalent to Affine3::from_translation(translation) * Affine3::from_quat(rotation)
Sourcepub fn from_mat4(m: Mat4) -> Affine3
pub fn from_mat4(m: Mat4) -> Affine3
The given Mat4 must be an affine transform,
i.e. contain no perspective transform.
Sourcepub fn to_scale_rotation_translation(&self) -> (Vec3, Quat, Vec3)
pub fn to_scale_rotation_translation(&self) -> (Vec3, Quat, Vec3)
Extracts scale, rotation and translation from self.
The transform is expected to be non-degenerate and without shearing, or the output will be invalid.
Panics
Will panic if the determinant self.matrix3 is zero or if the resulting scale
vector contains any zero elements when glam_assert is enabled.
Sourcepub fn look_to_lh(eye: Vec3, dir: Vec3, up: Vec3) -> Affine3
pub fn look_to_lh(eye: Vec3, dir: Vec3, up: Vec3) -> Affine3
Creates a left-handed view transform using a camera position, an up direction, and a facing direction.
For a view coordinate system with +X=right, +Y=up and +Z=forward.
Sourcepub fn look_to_rh(eye: Vec3, dir: Vec3, up: Vec3) -> Affine3
pub fn look_to_rh(eye: Vec3, dir: Vec3, up: Vec3) -> Affine3
Creates a right-handed view transform using a camera position, an up direction, and a facing direction.
For a view coordinate system with +X=right, +Y=up and +Z=back.
Sourcepub fn look_at_lh(eye: Vec3, center: Vec3, up: Vec3) -> Affine3
pub fn look_at_lh(eye: Vec3, center: Vec3, up: Vec3) -> Affine3
Creates a left-handed view transform using a camera position, an up direction, and a focal
point.
For a view coordinate system with +X=right, +Y=up and +Z=forward.
Panics
Will panic if up is not normalized when glam_assert is enabled.
Sourcepub fn look_at_rh(eye: Vec3, center: Vec3, up: Vec3) -> Affine3
pub fn look_at_rh(eye: Vec3, center: Vec3, up: Vec3) -> Affine3
Creates a right-handed view transform using a camera position, an up direction, and a focal
point.
For a view coordinate system with +X=right, +Y=up and +Z=back.
Panics
Will panic if up is not normalized when glam_assert is enabled.
Sourcepub fn transform_point3(&self, rhs: Vec3) -> Vec3
pub fn transform_point3(&self, rhs: Vec3) -> Vec3
Transforms the given 3D points, applying shear, scale, rotation and translation.
Sourcepub fn transform_vector3(&self, rhs: Vec3) -> Vec3
pub fn transform_vector3(&self, rhs: Vec3) -> Vec3
Transforms the given 3D vector, applying shear, scale and rotation (but NOT translation).
To also apply translation, use Self::transform_point3() instead.
Sourcepub fn is_finite(&self) -> bool
pub fn is_finite(&self) -> bool
Returns true if, and only if, all elements are finite.
If any element is either NaN, positive or negative infinity, this will return
false.
Sourcepub fn abs_diff_eq(&self, rhs: Affine3, max_abs_diff: f32) -> bool
pub fn abs_diff_eq(&self, rhs: Affine3, max_abs_diff: f32) -> bool
Returns true if the absolute difference of all elements between self and rhs
is less than or equal to max_abs_diff.
This can be used to compare if two 3x4 matrices contain similar elements. It works
best when comparing with a known value. The max_abs_diff that should be used used
depends on the values being compared against.
For more see comparing floating point numbers.
Sourcepub fn inverse(&self) -> Affine3
pub fn inverse(&self) -> Affine3
Return the inverse of this transform.
Note that if the transform is not invertible the result will be invalid.
Sourcepub fn as_daffine3(&self) -> DAffine3
pub fn as_daffine3(&self) -> DAffine3
Casts all elements of self to f64.